﻿using System;
using System.Windows;
using System.Windows.Controls;
using CompanySLApp.CompanyServiceReference;
using System.Collections.Generic;
using System.Data.Services.Client;

namespace CompanySLApp
{
    public partial class CompaniesList : UserControl
    {
        public CompaniesList()
        {
            InitializeComponent();
        }

        private void RefreshData()
        {
            Page.ShowLoadingLabel();
            CompanyServiceReference.CompanyServiceClient client = new CompanyServiceReference.CompanyServiceClient();
            client.GetCompanyListCompleted += new EventHandler<CompanySLApp.CompanyServiceReference.GetCompanyListCompletedEventArgs>(client_GetCompaniesCompleted);
            client.GetCompanyListAsync();
        }

        void client_GetCompaniesCompleted(object sender, CompanyServiceReference.GetCompanyListCompletedEventArgs e)
        {
            if (e.Error == null)
            {
                this.CompaniesGrid.ItemsSource = null;
                this.CompaniesGrid.ItemsSource = e.Result;
                Page.HideLoadingLabel();
            }
        }

        private void RefreshDataAstoria()
        {
            var context = new AstoriaService.CompanyEntities(new Uri("http://localhost:2407/CompanyAstoriaService.svc", UriKind.RelativeOrAbsolute));
            DataServiceQuery<AstoriaService.Companies> query = context.Companies.Expand("Persons");
            query.BeginExecute((e) =>
                {
                    if (e.AsyncState != null)
                    {
                         DataServiceQuery<AstoriaService.Companies> result = e.AsyncState as DataServiceQuery<AstoriaService.Companies>;
                         var data = result.EndExecute(e);
                         if (data != null)
                         {
                             List<AstoriaService.Companies> list = new List<CompanySLApp.AstoriaService.Companies>(data);
                             Dispatcher.BeginInvoke(() =>
                                 {
                                     this.CompaniesGrid.ItemsSource = null;
                                     this.CompaniesGrid.ItemsSource = list;
                                 });
                         }
                    }
                    else
                    {
                        // errors
                    }

                }, query);
        }

        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            RefreshData();
            //RefreshDataAstoria();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            CompanyServiceReference.Companies selectedCompany = (CompanyServiceReference.Companies)(((Button)sender).Tag);
            Page.ShowCompanyControl(selectedCompany.CompanyId);
        }

        private void AddCompany_Click(object sender, RoutedEventArgs e)
        {
            Page.ShowCompanyControl();
        }

        private void DeleteCompany_Click(object sender, RoutedEventArgs e)
        {
            Page.ShowLoadingLabel();
            CompanyServiceReference.CompanyServiceClient client = new CompanyServiceReference.CompanyServiceClient();
            client.DeleteCompleted += new EventHandler<System.ComponentModel.AsyncCompletedEventArgs>(client_DeleteCompleted);
            client.DeleteAsync(((CompanyServiceReference.Companies)(((Button)sender).Tag)).CompanyId);
        }

        void client_DeleteCompleted(object sender, System.ComponentModel.AsyncCompletedEventArgs e)
        {
            if (e.Error == null)
            {
                RefreshData();
            }
            else
            {
                MessageBox.Show("Delete failed " + e.Error.ToString(), "Error", MessageBoxButton.OK);
                Page.HideLoadingLabel();
            }
        }

    }
}
